// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "bluedevil_sendfile.h"


Q_LOGGING_CATEGORY(BLUEDEVIL_SENDFILE_LOG, "org.kde.plasma.bluedevil.sendfile", QtInfoMsg)

