/********************************************************************************
** Form generated from reading UI file 'connecting.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTING_H
#define UI_CONNECTING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Connecting
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *connLabel;
    QProgressBar *progressBar;

    void setupUi(QWidget *Connecting)
    {
        if (Connecting->objectName().isEmpty())
            Connecting->setObjectName("Connecting");
        Connecting->resize(400, 299);
        verticalLayout = new QVBoxLayout(Connecting);
        verticalLayout->setObjectName("verticalLayout");
        connLabel = new QLabel(Connecting);
        connLabel->setObjectName("connLabel");
        connLabel->setTextFormat(Qt::PlainText);

        verticalLayout->addWidget(connLabel);

        progressBar = new QProgressBar(Connecting);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);

        verticalLayout->addWidget(progressBar);


        retranslateUi(Connecting);

        QMetaObject::connectSlotsByName(Connecting);
    } // setupUi

    void retranslateUi(QWidget *Connecting)
    {
        (void)Connecting;
    } // retranslateUi

};

namespace Ui {
    class Connecting: public Ui_Connecting {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECTING_H

