/********************************************************************************
** Form generated from reading UI file 'connect.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECT_H
#define UI_CONNECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Connect
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *connecting;
    QProgressBar *progressBar;

    void setupUi(QWidget *Connect)
    {
        if (Connect->objectName().isEmpty())
            Connect->setObjectName("Connect");
        Connect->resize(400, 300);
        verticalLayout = new QVBoxLayout(Connect);
        verticalLayout->setObjectName("verticalLayout");
        connecting = new QLabel(Connect);
        connecting->setObjectName("connecting");

        verticalLayout->addWidget(connecting);

        progressBar = new QProgressBar(Connect);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);

        verticalLayout->addWidget(progressBar);


        retranslateUi(Connect);

        QMetaObject::connectSlotsByName(Connect);
    } // setupUi

    void retranslateUi(QWidget *Connect)
    {
        (void)Connect;
    } // retranslateUi

};

namespace Ui {
    class Connect: public Ui_Connect {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECT_H

