/********************************************************************************
** Form generated from reading UI file 'requestpin.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REQUESTPIN_H
#define UI_REQUESTPIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DialogWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *pixmap;
    QLabel *descLabel;
    QLabel *label;
    QLineEdit *pin;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *DialogWidget)
    {
        if (DialogWidget->objectName().isEmpty())
            DialogWidget->setObjectName("DialogWidget");
        DialogWidget->resize(259, 138);
        DialogWidget->setMinimumSize(QSize(0, 0));
        gridLayout = new QGridLayout(DialogWidget);
        gridLayout->setObjectName("gridLayout");
        pixmap = new QLabel(DialogWidget);
        pixmap->setObjectName("pixmap");
        pixmap->setMinimumSize(QSize(64, 64));

        gridLayout->addWidget(pixmap, 0, 0, 1, 1);

        descLabel = new QLabel(DialogWidget);
        descLabel->setObjectName("descLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(descLabel->sizePolicy().hasHeightForWidth());
        descLabel->setSizePolicy(sizePolicy);
        descLabel->setText(QString::fromUtf8(""));
        descLabel->setWordWrap(true);

        gridLayout->addWidget(descLabel, 0, 1, 1, 1);

        label = new QLabel(DialogWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 1, 0, 1, 1);

        pin = new QLineEdit(DialogWidget);
        pin->setObjectName("pin");
        sizePolicy.setHeightForWidth(pin->sizePolicy().hasHeightForWidth());
        pin->setSizePolicy(sizePolicy);

        gridLayout->addWidget(pin, 1, 1, 1, 1);

        buttonBox = new QDialogButtonBox(DialogWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 2);


        retranslateUi(DialogWidget);

        QMetaObject::connectSlotsByName(DialogWidget);
    } // setupUi

    void retranslateUi(QWidget *DialogWidget)
    {
        pixmap->setText(QString());
        label->setText(tr2i18n("PIN:", nullptr));
        pin->setPlaceholderText(tr2i18n("1234", nullptr));
        (void)DialogWidget;
    } // retranslateUi

};

namespace Ui {
    class DialogWidget: public Ui_DialogWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REQUESTPIN_H

