/********************************************************************************
** Form generated from reading UI file 'failpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FAILPAGE_H
#define UI_FAILPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FailPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *failIcon;
    QLabel *failLbl;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *FailPage)
    {
        if (FailPage->objectName().isEmpty())
            FailPage->setObjectName("FailPage");
        FailPage->resize(400, 300);
        FailPage->setMaximumSize(QSize(600, 16777215));
        verticalLayout = new QVBoxLayout(FailPage);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        failIcon = new QLabel(FailPage);
        failIcon->setObjectName("failIcon");
        failIcon->setMaximumSize(QSize(48, 48));

        horizontalLayout->addWidget(failIcon);

        failLbl = new QLabel(FailPage);
        failLbl->setObjectName("failLbl");
        failLbl->setTextFormat(Qt::PlainText);
        failLbl->setWordWrap(true);

        horizontalLayout->addWidget(failLbl);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(FailPage);

        QMetaObject::connectSlotsByName(FailPage);
    } // setupUi

    void retranslateUi(QWidget *FailPage)
    {
        failLbl->setText(QString());
        (void)FailPage;
    } // retranslateUi

};

namespace Ui {
    class FailPage: public Ui_FailPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FAILPAGE_H

