/********************************************************************************
** Form generated from reading UI file 'selectfilediscover.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTFILEDISCOVER_H
#define UI_SELECTFILEDISCOVER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <ksqueezedtextlabel.h>

QT_BEGIN_NAMESPACE

class Ui_SelectFileDiscover
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QWidget *widget_2;
    QHBoxLayout *horizontalLayout_4;
    QHBoxLayout *discoverLayout;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    KSqueezedTextLabel *selectLbl;
    QPushButton *selectBtn;

    void setupUi(QWidget *SelectFileDiscover)
    {
        if (SelectFileDiscover->objectName().isEmpty())
            SelectFileDiscover->setObjectName("SelectFileDiscover");
        SelectFileDiscover->resize(658, 396);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SelectFileDiscover->sizePolicy().hasHeightForWidth());
        SelectFileDiscover->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(SelectFileDiscover);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setSizeConstraint(QLayout::SetMinimumSize);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(SelectFileDiscover);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        widget_2 = new QWidget(SelectFileDiscover);
        widget_2->setObjectName("widget_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(widget_2->sizePolicy().hasHeightForWidth());
        widget_2->setSizePolicy(sizePolicy1);
        horizontalLayout_4 = new QHBoxLayout(widget_2);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        discoverLayout = new QHBoxLayout();
        discoverLayout->setObjectName("discoverLayout");

        horizontalLayout_4->addLayout(discoverLayout);


        verticalLayout->addWidget(widget_2);

        widget = new QWidget(SelectFileDiscover);
        widget->setObjectName("widget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy2);
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(4, 4, 4, 4);
        selectLbl = new KSqueezedTextLabel(widget);
        selectLbl->setObjectName("selectLbl");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(selectLbl->sizePolicy().hasHeightForWidth());
        selectLbl->setSizePolicy(sizePolicy3);
        selectLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(selectLbl);

        selectBtn = new QPushButton(widget);
        selectBtn->setObjectName("selectBtn");
        selectBtn->setFlat(true);

        horizontalLayout->addWidget(selectBtn);


        verticalLayout->addWidget(widget);


        retranslateUi(SelectFileDiscover);

        QMetaObject::connectSlotsByName(SelectFileDiscover);
    } // setupUi

    void retranslateUi(QWidget *SelectFileDiscover)
    {
        label_2->setText(tr2i18n("Select a device from the list:", nullptr));
        selectLbl->setText(tr2i18n("Select one or more files:", nullptr));
        (void)SelectFileDiscover;
    } // retranslateUi

};

namespace Ui {
    class SelectFileDiscover: public Ui_SelectFileDiscover {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTFILEDISCOVER_H

