/****************************************************************************
** Meta object code from reading C++ file 'bluedevildaemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../bluedevil-6.7.2/src/kded/bluedevildaemon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluedevildaemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15BlueDevilDaemonE_t {};
} // unnamed namespace

template <> constexpr inline auto BlueDevilDaemon::qt_create_metaobjectdata<qt_meta_tag_ZN15BlueDevilDaemonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BlueDevilDaemon",
        "D-Bus Interface",
        "org.kde.BlueDevil",
        "initJobResult",
        "",
        "BluezQt::InitManagerJob*",
        "job",
        "initObexJobResult",
        "BluezQt::InitObexManagerJob*",
        "operationalChanged",
        "operational",
        "obexOperationalChanged",
        "agentRegisted",
        "BluezQt::PendingCall*",
        "call",
        "agentRequestedDefault",
        "obexAgentRegistered",
        "isOnline",
        "allDevices",
        "QMapDeviceInfo",
        "device",
        "DeviceInfo",
        "address",
        "startDiscovering",
        "timeout",
        "stopDiscovering"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'initJobResult'
        QtMocHelpers::SlotData<void(BluezQt::InitManagerJob *)>(3, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'initObexJobResult'
        QtMocHelpers::SlotData<void(BluezQt::InitObexManagerJob *)>(7, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 6 },
        }}),
        // Slot 'operationalChanged'
        QtMocHelpers::SlotData<void(bool)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'obexOperationalChanged'
        QtMocHelpers::SlotData<void(bool)>(11, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'agentRegisted'
        QtMocHelpers::SlotData<void(BluezQt::PendingCall *)>(12, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'agentRequestedDefault'
        QtMocHelpers::SlotData<void(BluezQt::PendingCall *)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'obexAgentRegistered'
        QtMocHelpers::SlotData<void(BluezQt::PendingCall *)>(16, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'isOnline'
        QtMocHelpers::MethodData<bool()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'allDevices'
        QtMocHelpers::MethodData<QMapDeviceInfo()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 19),
        // Method 'device'
        QtMocHelpers::MethodData<DeviceInfo(const QString &)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 21, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'startDiscovering'
        QtMocHelpers::MethodData<void(quint32)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 24 },
        }}),
        // Method 'stopDiscovering'
        QtMocHelpers::MethodData<void()>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BlueDevilDaemon, qt_meta_tag_ZN15BlueDevilDaemonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BlueDevilDaemon::staticMetaObject = { {
    QMetaObject::SuperData::link<KDEDModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BlueDevilDaemonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BlueDevilDaemonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15BlueDevilDaemonE_t>.metaTypes,
    nullptr
} };

void BlueDevilDaemon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BlueDevilDaemon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initJobResult((*reinterpret_cast<std::add_pointer_t<BluezQt::InitManagerJob*>>(_a[1]))); break;
        case 1: _t->initObexJobResult((*reinterpret_cast<std::add_pointer_t<BluezQt::InitObexManagerJob*>>(_a[1]))); break;
        case 2: _t->operationalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->obexOperationalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->agentRegisted((*reinterpret_cast<std::add_pointer_t<BluezQt::PendingCall*>>(_a[1]))); break;
        case 5: _t->agentRequestedDefault((*reinterpret_cast<std::add_pointer_t<BluezQt::PendingCall*>>(_a[1]))); break;
        case 6: _t->obexAgentRegistered((*reinterpret_cast<std::add_pointer_t<BluezQt::PendingCall*>>(_a[1]))); break;
        case 7: { bool _r = _t->isOnline();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { QMapDeviceInfo _r = _t->allDevices();
            if (_a[0]) *reinterpret_cast<QMapDeviceInfo*>(_a[0]) = std::move(_r); }  break;
        case 9: { DeviceInfo _r = _t->device((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DeviceInfo*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->startDiscovering((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 11: _t->stopDiscovering(); break;
        default: ;
        }
    }
}

const QMetaObject *BlueDevilDaemon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BlueDevilDaemon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BlueDevilDaemonE_t>.strings))
        return static_cast<void*>(this);
    return KDEDModule::qt_metacast(_clname);
}

int BlueDevilDaemon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDEDModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
