/********************************************************************************
** Form generated from reading UI file 'pairing.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PAIRING_H
#define UI_PAIRING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Pairing
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *connectingLbl;
    QProgressBar *progressBar;
    QFrame *frame;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *pinNumber;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *confirmLbl;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Pairing)
    {
        if (Pairing->objectName().isEmpty())
            Pairing->setObjectName("Pairing");
        Pairing->resize(400, 300);
        verticalLayout = new QVBoxLayout(Pairing);
        verticalLayout->setObjectName("verticalLayout");
        connectingLbl = new QLabel(Pairing);
        connectingLbl->setObjectName("connectingLbl");
        connectingLbl->setTextFormat(Qt::PlainText);

        verticalLayout->addWidget(connectingLbl);

        progressBar = new QProgressBar(Pairing);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(0);

        verticalLayout->addWidget(progressBar);

        frame = new QFrame(Pairing);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(frame);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        pinNumber = new QLabel(frame);
        pinNumber->setObjectName("pinNumber");
        pinNumber->setMinimumSize(QSize(22, 22));
        pinNumber->setFrameShape(QFrame::NoFrame);
        pinNumber->setFrameShadow(QFrame::Raised);
        pinNumber->setLineWidth(0);

        horizontalLayout_2->addWidget(pinNumber);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addWidget(frame);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(50, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        confirmLbl = new QLabel(Pairing);
        confirmLbl->setObjectName("confirmLbl");
        confirmLbl->setEnabled(true);
        confirmLbl->setAlignment(Qt::AlignCenter);
        confirmLbl->setWordWrap(true);

        horizontalLayout->addWidget(confirmLbl);

        horizontalSpacer_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Pairing);

        QMetaObject::connectSlotsByName(Pairing);
    } // setupUi

    void retranslateUi(QWidget *Pairing)
    {
        pinNumber->setText(QString());
        confirmLbl->setText(QString());
        (void)Pairing;
    } // retranslateUi

};

namespace Ui {
    class Pairing: public Ui_Pairing {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PAIRING_H

