/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<devicesproxymodel.h>)
#  include <devicesproxymodel.h>
#endif
#if __has_include(<devicesstateproxymodel.h>)
#  include <devicesstateproxymodel.h>
#endif
#if __has_include(<launchapp.h>)
#  include <launchapp.h>
#endif
#if __has_include(<utils.h>)
#  include <utils.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_bluetooth()
{
    qmlRegisterModule("org.kde.plasma.private.bluetooth", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DevicesProxyModel>("org.kde.plasma.private.bluetooth", 254);
    qmlRegisterTypesAndRevisions<DevicesStateProxyModel>("org.kde.plasma.private.bluetooth", 254);
    qmlRegisterEnum<DevicesStateProxyModel::Roles>("DevicesStateProxyModel::Roles");
    qmlRegisterTypesAndRevisions<LaunchApp>("org.kde.plasma.private.bluetooth", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QIdentityProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<Utils>("org.kde.plasma.private.bluetooth", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.bluetooth", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmaprivatebluetoothRegistration("org.kde.plasma.private.bluetooth", qml_register_types_org_kde_plasma_private_bluetooth);
