/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was kded_bluedevil.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KDEDBLUEDEVIL_H
#define KDEDBLUEDEVIL_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "../../interfaces/kded_bluedevil_types.h"

/*
 * Proxy class for interface org.kde.BlueDevil
 */
class OrgKdeBlueDevilInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.BlueDevil"; }

public:
    OrgKdeBlueDevilInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeBlueDevilInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QMapDeviceInfo> allDevices()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("allDevices"), argumentList);
    }

    inline QDBusPendingReply<DeviceInfo> device(const QString &address)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(address);
        return asyncCallWithArgumentList(QStringLiteral("device"), argumentList);
    }

    inline QDBusPendingReply<bool> isOnline()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isOnline"), argumentList);
    }

    inline QDBusPendingReply<> startDiscovering(uint timeout)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(timeout);
        return asyncCallWithArgumentList(QStringLiteral("startDiscovering"), argumentList);
    }

    inline QDBusPendingReply<> stopDiscovering()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("stopDiscovering"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    using BlueDevil = ::OrgKdeBlueDevilInterface;
  }
}

#endif
