/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was kded_obexftp.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KDEDOBEXFTP_H
#define KDEDOBEXFTP_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.BlueDevil.ObexFtp
 */
class OrgKdeBlueDevilObexFtpInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.BlueDevil.ObexFtp"; }

public:
    OrgKdeBlueDevilObexFtpInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeBlueDevilObexFtpInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> cancelTransfer(const QString &transfer)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(transfer);
        return asyncCallWithArgumentList(QStringLiteral("cancelTransfer"), argumentList);
    }

    inline QDBusPendingReply<bool> isOnline()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isOnline"), argumentList);
    }

    inline QDBusPendingReply<QString> preferredTarget(const QString &address)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(address);
        return asyncCallWithArgumentList(QStringLiteral("preferredTarget"), argumentList);
    }

    inline QDBusPendingReply<QString> session(const QString &address, const QString &target)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(address) << QVariant::fromValue(target);
        return asyncCallWithArgumentList(QStringLiteral("session"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace BlueDevil {
      using ObexFtp = ::OrgKdeBlueDevilObexFtpInterface;
    }
  }
}

#endif
