/********************************************************************************
** Form generated from reading UI file 'discover.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DISCOVER_H
#define UI_DISCOVER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Discover
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QListView *devices;
    QHBoxLayout *horizontalLayout_2;

    void setupUi(QWidget *Discover)
    {
        if (Discover->objectName().isEmpty())
            Discover->setObjectName("Discover");
        Discover->resize(571, 525);
        verticalLayout_2 = new QVBoxLayout(Discover);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        devices = new QListView(Discover);
        devices->setObjectName("devices");
        devices->setIconSize(QSize(48, 48));
        devices->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(devices);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");

        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(Discover);

        QMetaObject::connectSlotsByName(Discover);
    } // setupUi

    void retranslateUi(QWidget *Discover)
    {
        (void)Discover;
    } // retranslateUi

};

namespace Ui {
    class Discover: public Ui_Discover {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DISCOVER_H

