// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "bluedevil_kio_obexftp.h"


Q_LOGGING_CATEGORY(BLUEDEVIL_KIO_OBEXFTP_LOG, "org.kde.plasma.bluedevil.kioobexftp", QtInfoMsg)

