/********************************************************************************
** Form generated from reading UI file 'discover.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DISCOVER_H
#define UI_DISCOVER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kbusyindicatorwidget.h"

QT_BEGIN_NAMESPACE

class Ui_Discover
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QLineEdit *searchField;
    QListView *deviceView;
    QCheckBox *showUnnamedDevicesCheckBox;
    QHBoxLayout *horizontalLayout_2;
    KBusyIndicatorWidget *busyIndicator;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QCheckBox *manualPin;
    QLineEdit *pinText;

    void setupUi(QWidget *Discover)
    {
        if (Discover->objectName().isEmpty())
            Discover->setObjectName("Discover");
        Discover->resize(571, 444);
        verticalLayout_2 = new QVBoxLayout(Discover);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        searchField = new QLineEdit(Discover);
        searchField->setObjectName("searchField");
        searchField->setClearButtonEnabled(true);

        verticalLayout->addWidget(searchField);

        deviceView = new QListView(Discover);
        deviceView->setObjectName("deviceView");
        deviceView->setIconSize(QSize(48, 48));
        deviceView->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);

        verticalLayout->addWidget(deviceView);

        showUnnamedDevicesCheckBox = new QCheckBox(Discover);
        showUnnamedDevicesCheckBox->setObjectName("showUnnamedDevicesCheckBox");

        verticalLayout->addWidget(showUnnamedDevicesCheckBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        busyIndicator = new KBusyIndicatorWidget(Discover);
        busyIndicator->setObjectName("busyIndicator");

        horizontalLayout_2->addWidget(busyIndicator);

        horizontalSpacer_2 = new QSpacerItem(4, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        label = new QLabel(Discover);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        manualPin = new QCheckBox(Discover);
        manualPin->setObjectName("manualPin");
        manualPin->setChecked(false);

        horizontalLayout_2->addWidget(manualPin);

        pinText = new QLineEdit(Discover);
        pinText->setObjectName("pinText");
        pinText->setEnabled(false);
        pinText->setMinimumSize(QSize(100, 0));
        pinText->setMaximumSize(QSize(50, 40));
        pinText->setReadOnly(false);

        horizontalLayout_2->addWidget(pinText);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(Discover);

        QMetaObject::connectSlotsByName(Discover);
    } // setupUi

    void retranslateUi(QWidget *Discover)
    {
        searchField->setPlaceholderText(tr2i18n("Search\342\200\246", nullptr));
        showUnnamedDevicesCheckBox->setText(tr2i18n("Show unnamed devices", nullptr));
        label->setText(tr2i18n("Scanning\342\200\246", nullptr));
        manualPin->setText(tr2i18n("Manual PIN:", nullptr));
        pinText->setPlaceholderText(tr2i18n("0000", nullptr));
        (void)Discover;
    } // retranslateUi

};

namespace Ui {
    class Discover: public Ui_Discover {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DISCOVER_H

